==> haskell-lsp-test-0.14.1.0-203-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-test
version:              0.14.1.0
visibility:           public
id:                   lsp-test-0.14.1.0-LtBKkHh95MQG4zNO3ig8yD
key:                  lsp-test-0.14.1.0-LtBKkHh95MQG4zNO3ig8yD
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  e901fac00240283bbdcfb6cdc82aa057
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav:Control.Applicative.Combinators,
    Language.LSP.Test,
    Language.LSP.Types from lsp-types-1.6.0.1-EbXi7nqThAk8EPWs1KGH8W:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.6.0.1-EbXi7nqThAk8EPWs1KGH8W:Language.LSP.Types.Capabilities

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test
hs-libraries:         HSlsp-test-0.14.1.0-LtBKkHh95MQG4zNO3ig8yD
depends:
    Diff-0.4.1-8NUfR4WKqY5H9Ttf0Koorw
    Glob-0.10.2-CfMdUOLNwWWADTihQDYGgB
    aeson-2.1.2.1-5BFfk7iI7w6HPWzhbIRzqn
    aeson-pretty-0.8.10-CwXo2PdeXuRCVi5BLDBjO7
    ansi-terminal-1.0.2-J3CYMek3QCg8mQRiAxriIL
    async-2.2.5-D49NPDHTd69BKX3jfj3d2D base-4.17.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.5-DDWPQ14xH3hGmrfIffY2rx
    conduit-1.3.6.1-8kXjnDSt7SWIbXyadQmMao
    conduit-parse-0.2.1.1-9wCIYw2IrRcCkOkCknR283 containers-0.6.7
    data-default-0.7.1.1-1dWAwpuUe04Bvh1yMI7wxn directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2 lens-5.3-4eslcvGQhMj5JgydAUw2Le
    lsp-1.6.0.0-508CFNSfxRk5osYUa0HzyX
    lsp-types-1.6.0.1-EbXi7nqThAk8EPWs1KGH8W mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav process-1.6.18.0
    some-1.0.6-C8SVhXoLo1W43DiM5WqKp8 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unordered-containers-0.2.20-2eRdi4Eno3wAApPXuoC33k

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-test-0.14.1.0-207-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-test
version:              0.14.1.0
visibility:           public
id:                   lsp-test-0.14.1.0-C40UyL4AFL02ABGK9EHEF0
key:                  lsp-test-0.14.1.0-C40UyL4AFL02ABGK9EHEF0
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  b67247ab7b11fed77ef5df925d5ee37f
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav:Control.Applicative.Combinators,
    Language.LSP.Test,
    Language.LSP.Types from lsp-types-1.6.0.1-G3Xvup4znTyBBsuZlFc00V:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.6.0.1-G3Xvup4znTyBBsuZlFc00V:Language.LSP.Types.Capabilities

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test
hs-libraries:         HSlsp-test-0.14.1.0-C40UyL4AFL02ABGK9EHEF0
depends:
    Diff-0.4.1-7aKWbaxEjXuGNL7kuqoq7g
    Glob-0.10.2-EvqJcDWC0SV2VHQSxG9501
    aeson-2.1.2.1-6jLf9XnWqJCFwZgyNgcXK5
    aeson-pretty-0.8.10-GV7QdDzqLCy55dCd8lp47a
    ansi-terminal-1.0.2-2SdInZ2XzOpHxNy7zA9Y2f
    async-2.2.5-71qvS8UVmexLJ5VLFM0sV7 base-4.17.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.5-Csk8ESUdSTIDUtzF79GMjX
    conduit-1.3.6.1-D5gtRvoNCm9CE8oOCirzgp
    conduit-parse-0.2.1.1-InuNwDf2aU42IDW2cqFkG0 containers-0.6.7
    data-default-0.7.1.1-7mS5xpY4EnxodGGT6vPB1 directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2 lens-5.3-FqQ28IkTmSZ8BNGxtZdro6
    lsp-1.6.0.0-6dFR8cP8bZQE5cAoy6zv9h
    lsp-types-1.6.0.1-G3Xvup4znTyBBsuZlFc00V mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav process-1.6.18.0
    some-1.0.6-1SD3iHUG5HqJJvyBvrawCQ text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unordered-containers-0.2.20-C8J7H3CMcSh2WWoYFsvixL

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
